<?php
/**
 * @package    NovinoPay_prestashop payment module for 1.6 and less
 * @author     NovinoPay
 * @copyright  2022  NovinoPay.com
 * @link       https://NovinoPay.com
 * @version    1
 */
if (!defined('_PS_VERSION_'))
    exit;

class novinopay_prestashop extends PaymentModule
{

    private $_html = '';
    private $_postErrors = array();

    public function __construct()
    {

        $this->name = 'novinopay_prestashop';
        $this->tab = 'payments_gateways';
        $this->version = '1';
        $this->author = 'NovinoPay';
        $this->currencies = true;
        $this->currencies_mode = 'radio';
        parent::__construct();
        $this->displayName = $this->l('درگاه پرداخت نوینو');
        $this->description = $this->l('درگاه پرداخت نوینو');
        $this->confirmUninstall = $this->l('ماژول درگاه پرداخت نوینو حذف شود؟');
        if (!sizeof(Currency::checkPaymentCurrencies($this->id)))
            $this->warning = $this->l('هیچ ارزی برای استفاده وجود ندارد.');
        $config = Configuration::getMultiple(array('novinopay_prestashop_API'));
        if (!isset($config['novinopay_prestashop_API']))
            $this->warning = $this->l('لطفا کد درگاه (مرچنت) را وارد نمایید.');

    }

    public function install()
    {
        if (!parent::install() || !Configuration::updateValue('novinopay_prestashop_API', '') || !Configuration::updateValue('novinopay_prestashop_LOGO', '') || !Configuration::updateValue('novinopay_prestashop_HASH_KEY', $this->hash_key()) || !$this->registerHook('payment') || !$this->registerHook('paymentReturn'))
            return false;
        else
            return true;
    }

    public function uninstall()
    {
        if (!Configuration::deleteByName('novinopay_prestashop_API') || !Configuration::deleteByName('novinopay_prestashop_LOGO') || !Configuration::deleteByName('novinopay_prestashop_HASH_KEY') || !parent::uninstall())
            return false;
        else
            return true;
    }

    public function hash_key()
    {
        $en = array('a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z');
        $one = rand(1, 26);
        $two = rand(1, 26);
        $three = rand(1, 26);
        return $hash = $en[$one] . rand(0, 9) . rand(0, 9) . $en[$two] . $en[$tree] . rand(0, 9) . rand(10, 99);
    }

    public function getContent()
    {

        if (Tools::isSubmit('novinopay_prestashop_setting')) {

            Configuration::updateValue('novinopay_prestashop_API', $_POST['novinopay_API']);
            Configuration::updateValue('novinopay_prestashop_LOGO', $_POST['novinopay_LOGO']);
            $this->_html .= '<div class="conf confirm">' . $this->l('Settings updated') . '</div>';
        }

        $this->_generateForm();
        return $this->_html;
    }

    private function _generateForm()
    {
        $this->_html .= '<div align="center"><form action="' . $_SERVER['REQUEST_URI'] . '" method="post">';
        $this->_html .= $this->l(' کد درگاه پرداخت (مرچنت) را وارد نمایید ') . '<br/><br/>';
        $this->_html .= '<input type="text" name="novinopay_API" value="' . Configuration::get('novinopay_prestashop_API') . '" ><br/><br/>';
        $this->_html .= '<input type="submit" name="novinopay_prestashop_setting"';
        $this->_html .= 'value="' . $this->l('ذخیره') . '" class="button" />';
        $this->_html .= '</form><br/></div>';
    }

    public function do_payment($cart)
    {

        if (extension_loaded('curl')) {

            $novinopayPin = Configuration::get('novinopay_prestashop_API');
            $amount = floatval(number_format($cart->getOrderTotal(true, 3), 2, '.', ''));
            $callbackUrl = (Configuration::get('PS_SSL_ENABLED') ? 'https://' : 'http://') . $_SERVER['HTTP_HOST'] . __PS_BASE_URI__ . 'modules/novinopay_prestashop/novinopay.php?do=call_back&id=' . $cart->id . '&amount=' . $amount;
            $orderId = $cart->id;
            $txt = 'پرداخت سفارش شماره: ' . $cart->id;

            $currency_id = $cart->id_currency;

            foreach (Currency::getCurrencies() as $key => $currency) {
                if ($currency['id_currency'] == $currency_id) {
                    $currency_iso_code = $currency['iso_code'];
                }
            }

            $rial_amount = round($amount);
            if ($currency_iso_code != 'IRR') {
                $rial_amount = $amount * 10;
            } else $rial_amount = $amount;

            $params = [
                'merchant_id' => $novinopayPin,
                'amount' => intval($rial_amount),
                'description' => "{$txt}",
                'invoice_id' => "{$orderId}",
                'callback_url' => $callbackUrl,
                'plugin' => 'Prestashop_1.6'
            ];


            $result = self::SendRequestTonovinopay('request', json_encode($params, JSON_UNESCAPED_UNICODE));

            $hash = Configuration::get('novinopay_prestashop_HASH');
            $_SESSION['order' . $orderId] = md5($orderId . $amount . $hash);

            if (isset($result) && isset($result->status) && $result->status == 100) {
                echo $this->success($this->l('در حال ارجاع به درگاه پرداخت ...'));
                header('Location: ' . $result->data->payment_url);

            } elseif (isset($result) && isset($result->status) && $result->status != 100) {
                echo $this->error($this->l('مشکلی در اتصال به درگاه بانک وجود دارد.') . ' (' . $result->message . ')');
            } else {
                echo $this->error($this->l('امکان اتصال به درگاه بانک وجود ندارد.'));
            }
        } else {
            echo $this->error('تابع cURL در سرور فعال نمی باشد');
        }
    }

    public function error($str)
    {
        return '<div class="alert error">' . $str . '</div>';
    }

    public function success($str)
    {
        echo '<div class="conf confirm">' . $str . '</div>';
    }

    public function hookPayment($params)
    {
        global $smarty;
        $smarty->assign('novinopay_prestashop_logo', Configuration::get('novinopay_prestashop_LOGO'));
        if ($this->active)
            return $this->display(__FILE__, 'novinopaypayment.tpl');
    }

    public function hookPaymentReturn($params)
    {
        if ($this->active)
            return $this->display(__FILE__, 'novinopayconfirmation.tpl');
    }


	public function SendRequestTonovinopay($action, $params)
	{
		try {
			$curl = curl_init('https://api.novinopay.com/payment/ipg/v2/' . $action);
			curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type' => 'application/json'));
			curl_setopt($curl, CURLOPT_POSTFIELDS, $params);
			curl_setopt($curl, CURLOPT_TIMEOUT, 50);
			curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			$result = curl_exec($curl);

			return json_decode($result);
		} catch (Exception $ex) {
			return false;
		}
	}


}


